﻿using System;
using System.IO.Ports;
using System.Media;
using System.Text;
using System.Threading;
using System.Windows.Media;

namespace Theatre
{
    class AppContext
    {
        private SynchronizationContext _synchronizationContext;
        // 串口类
        private SerialPort _serialPort;

        private static AppContext _appContext;

        private AppContext() { }

        public static AppContext GetAppContext()
        {
            if (_appContext == null)
            {
                _appContext = new AppContext();
                // 获取UI线程同步上下文
                _appContext._synchronizationContext = SynchronizationContext.Current;
            }
            return _appContext;
        }

        public SerialPort SerialPort
        {
            set
            {
                if (value == null)
                {
                    PortOpen = false;
                    MainWindow.Status.Content = "未连接";
                    MainWindow.Status.ToolTip = "设备未连接";
                    MainWindow.Status.Foreground = new SolidColorBrush(Colors.Red);
                }
                else
                {
                    PortOpen = true;
                    MainWindow.Status.Content = "已连接";
                    MainWindow.Status.ToolTip = "设备已连接";
                    MainWindow.Status.Foreground = new SolidColorBrush(Colors.Green);
                }
                _serialPort = value;
            }
            get
            {
                return _serialPort;
            }
        }

        // 打开串口标志位
        public bool PortOpen { set; get; }

        public void DataReceived(object sender, SerialDataReceivedEventArgs e)
        {
            try
            {
                // Comm.BytesToRead 中为要读入的字节长度
                var len = _serialPort.BytesToRead;
                var readBuffer = new byte[len];
                // 将数据读入缓存
                _serialPort.Read(readBuffer, 0, len);
                // 处理 readBuffer 中的数据，自定义处理过程
                var msg = Encoding.Default.GetString(readBuffer, 0, len);
                Console.Write(msg);
                var fileName = "";
                switch (msg)
                {
                    case "1":
                        var soundPlayer1 = new SoundPlayer(Properties.Settings.Default.Audio1);
                        soundPlayer1.Load();
                        soundPlayer1.Play();
                        fileName = soundPlayer1.SoundLocation;
                        break;
                    case "2":
                        var soundPlayer2 = new SoundPlayer(Properties.Settings.Default.Audio2);
                        soundPlayer2.Load();
                        soundPlayer2.Play();
                        fileName = soundPlayer2.SoundLocation;
                        break;
                    case "3":
                        var soundPlayer3 = new SoundPlayer(Properties.Settings.Default.Audio3);
                        soundPlayer3.Load();
                        soundPlayer3.Play();
                        fileName = soundPlayer3.SoundLocation;
                        break;
                    case "4":
                        var soundPlayer4 = new SoundPlayer(Properties.Settings.Default.Audio4);
                        soundPlayer4.Load();
                        soundPlayer4.Play();
                        fileName = soundPlayer4.SoundLocation;
                        break;
                    case "5":
                        var soundPlayer5 = new SoundPlayer(Properties.Settings.Default.Audio5);
                        soundPlayer5.Load();
                        soundPlayer5.Play();
                        fileName = soundPlayer5.SoundLocation;
                        break;
                    case "6":
                        var soundPlayer6 = new SoundPlayer(Properties.Settings.Default.Audio6);
                        soundPlayer6.Load();
                        soundPlayer6.Play();
                        fileName = soundPlayer6.SoundLocation;
                        break;
                }
                // 委托执行
                ThreadProcSafePost(fileName);
            }
            catch (Exception ex)
            {
                Console.WriteLine("接收数据异常！具体原因：" + ex.Message);
            }
        }

        private void ThreadProcSafePost(string text)
        {
            _synchronizationContext.Post(SetTextSafePost, text);
        }

        private void SetTextSafePost(object text)
        {
            var fileName = (string)text;
            fileName = fileName.Substring(fileName.LastIndexOf("\\", StringComparison.Ordinal) + 1);
            MainWindow.FileLabel.Content = fileName;
            MainWindow.FileLabel.ToolTip = fileName;
        }
    }
}
